@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -252,8 +252,9 @@ public class AquaComboBoxUI extends BasicComboBoxUI implements Sizeable {
                         if (editor instanceof AquaCustomComboTextField) {
                             ((AquaCustomComboTextField)editor).selectAll();
                         }
+                    } else {
+                        action.actionPerformed(e);
                     }
-                    action.actionPerformed(e);
                 }
             });
         }
@@ -323,8 +324,6 @@ public class AquaComboBoxUI extends BasicComboBoxUI implements Sizeable {
         actionMap.put("aquaSelectPageDown", highlightPageDownAction);
 
         actionMap.put("aquaHidePopup", hideAction);
-        actionMap.put("aquaOpenPopupOrhighlightLast", openPopupOrHighlightLast);
-        actionMap.put("aquaOpenPopupOrhighlightFirst", openPopupOrHighlightFirst);
 
         SwingUtilities.replaceUIActionMap(comboBox, actionMap);
     }
@@ -455,31 +454,6 @@ public class AquaComboBoxUI extends BasicComboBoxUI implements Sizeable {
     }
 
     class AquaComboBoxLayoutManager extends BasicComboBoxUI.ComboBoxLayoutManager {
-        protected Rectangle rectangleForCurrentValue() {
-            int width = comboBox.getWidth();
-            int height = comboBox.getBorder() == null ? 22 : comboBox.getHeight();
-            Insets insets = getInsets();
-            int buttonSize = height - (insets.top + insets.bottom);
-            if ( arrowButton != null )  {
-                buttonSize = arrowButton.getWidth();
-            }
-            int midHeight = (comboBox.getHeight() - height - (insets.top + insets.bottom)) / 2 - 1;
-            if (midHeight < 0) {
-                midHeight = 0;
-            }
-
-            if (comboBox.getComponentOrientation().isLeftToRight()) {
-                return new Rectangle(insets.left, insets.top + midHeight,
-                        width - (insets.left + insets.right + buttonSize) + 3,
-                        height - (insets.top + insets.bottom));
-            }
-            else {
-                return new Rectangle(insets.left + buttonSize, insets.top + midHeight,
-                        width - (insets.left + insets.right + buttonSize) + 3,
-                        height - (insets.top + insets.bottom));
-            }
-        }
-
         public void layoutContainer(final Container parent) {
             if (arrowButton != null && !comboBox.isEditable()) {
                 final Insets insets = comboBox.getInsets();
@@ -503,6 +477,8 @@ public class AquaComboBoxUI extends BasicComboBoxUI implements Sizeable {
 
             if (editor != null) {
                 final Rectangle editorRect = rectangleForCurrentValue();
+                editorRect.width += 4;
+                editorRect.height += 1;
                 editor.setBounds(editorRect);
             }
         }
@@ -606,27 +582,6 @@ public class AquaComboBoxUI extends BasicComboBoxUI implements Sizeable {
         }
     };
 
-    @SuppressWarnings("serial") // anonymous class
-    private final Action openPopupOrHighlightLast = new ComboBoxAction() {
-        @Override
-        void performComboBoxAction(final AquaComboBoxUI ui) {
-            final int size = listBox.getModel().getSize();
-            listBox.setSelectedIndex(size - 1);
-            listBox.ensureIndexIsVisible(size - 1);
-            comboBox.setSelectedIndex(ui.getPopup().getList().getSelectedIndex());
-        }
-    };
-
-    @SuppressWarnings("serial") // anonymous class
-    private final Action openPopupOrHighlightFirst = new ComboBoxAction() {
-        @Override
-        void performComboBoxAction(final AquaComboBoxUI ui) {
-           listBox.setSelectedIndex(0);
-           listBox.ensureIndexIsVisible(0);
-           comboBox.setSelectedIndex(ui.getPopup().getList().getSelectedIndex());
-        }
-    };
-
     public void applySizeFor(final JComponent c, final Size size) {
         if (arrowButton == null) return;
         final Border border = arrowButton.getBorder();
@@ -643,8 +598,7 @@ public class AquaComboBoxUI extends BasicComboBoxUI implements Sizeable {
         final boolean editable = comboBox.isEditable();
 
         final Dimension size;
-        if (!editable && arrowButton != null && arrowButton instanceof AquaComboBoxButton) {
-            final AquaComboBoxButton button = (AquaComboBoxButton)arrowButton;
+        if (!editable && arrowButton instanceof final AquaComboBoxButton button) {
             final Insets buttonInsets = button.getInsets();
             //  Insets insets = comboBox.getInsets();
             final Insets insets = new Insets(0, 5, 0, 25);//comboBox.getInsets();
